@@ -1,32 +1,39 @@
-from gi.repository import GLib
 from gi.repository import Gtk
-from gi.repository import Gio
 import sys
 
 class MyWindow(Gtk.ApplicationWindow):
+    # a window
     def __init__(self, app):
         Gtk.Window.__init__(self, title="CheckButton Example", application=app)
         self.set_default_size(300, 100)
         self.set_border_width(10)
 
-        # a new checkbutton with a label, connected with the callback
-        button = Gtk.CheckButton.new_with_label("Show Title")
+        # a new checkbutton
+        button = Gtk.CheckButton()
+        #  with a label
+        button.set_label("Show Title")
+        # connect the signal "toggled" emitted by the checkbutton
+        # with the callback function toggled_cb
         button.connect("toggled", self.toggled_cb)
-        # default: is active
+        # by default, the checkbutton is active
         button.set_active(True)
 
+        # add the checkbutton to the window
         self.add(button)
 
-    # the button operates on the window
+    # callback function
     def toggled_cb(self, button):
+        # if the togglebutton is active, set the title of the window
+        # as "Checkbutton Example"
         if button.get_active():
             self.set_title("CheckButton Example")
+        # else, set it as "" (empty string)
         else:
             self.set_title("")
 
 class MyApplication(Gtk.Application):
     def __init__(self):
-        Gtk.Application.__init__(self, application_id="org.gtk.example.grid")
+        Gtk.Application.__init__(self)
 
     def do_activate(self):
         win = MyWindow(self)
