@@ -1,26 +1,25 @@
-from gi.repository import GLib
 from gi.repository import Gtk
-from gi.repository import Gio
 import sys
 
 class MyWindow(Gtk.ApplicationWindow):
+    # create a window
     def __init__(self, app):
         Gtk.Window.__init__(self, title="Welcome to GNOME", application=app)
-        
-class MyImage(Gtk.Image):
-    def __init__(self):
-        Gtk.Image.__init__(self)
-        self.set_from_file("gnome-image.png")
-        
+        self.set_default_size(300, 300)
+
+        # create an image
+        image = Gtk.Image()
+        # set the content of the image as the file filename.png
+        image.set_from_file("gnome-image.png")
+        # add the image to the window
+        self.add(image)
+
 class MyApplication(Gtk.Application):
     def __init__(self):
-        Gtk.Application.__init__(self, application_id="org.gtk.example.grid")
-        
+        Gtk.Application.__init__(self)
+
     def do_activate(self):
         win = MyWindow(self)
-        win.set_default_size(300, 300)
-        win.set_position(Gtk.WindowPosition.CENTER)
-        win.add(MyImage())
         win.show_all()
 
     def do_startup(self):
