@@ -1,7 +1,7 @@
 from gi.repository import Gtk
 import sys
 
-class SeparatorsWindow(Gtk.ApplicationWindow):
+class MyWindow(Gtk.ApplicationWindow):
     def __init__(self, app):
         Gtk.Window.__init__(self, title="Separator Example", application=app)
 
@@ -15,28 +15,30 @@ class SeparatorsWindow(Gtk.ApplicationWindow):
         label3 = Gtk.Label()
         label3.set_text("On the left, a vertical separator.")
 
-        # a horizontal and a vertical separator
+        # a horizontal separator
         hseparator = Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL)
+        # a vertical separator
         vseparator = Gtk.Separator(orientation=Gtk.Orientation.VERTICAL)
 
-        # a grid to attach them
+        # a grid to attach labels and separators
         grid = Gtk.Grid()
-        grid.attach(label1, 1, 1, 3, 1)
-        grid.attach(hseparator, 1, 2, 3, 1)
-        grid.attach(label2, 1, 3, 1, 1)
-        grid.attach(vseparator, 2, 3, 1, 1)
-        grid.attach(label3, 3, 3, 1, 1)
+        grid.attach(label1, 0, 0, 3, 1)
+        grid.attach(hseparator, 0, 1, 3, 1)
+        grid.attach(label2, 0, 2, 1, 1)
+        grid.attach(vseparator, 1, 2, 1, 1)
+        grid.attach(label3, 2, 2, 1, 1)
         grid.set_column_homogeneous(True)
+        # add the grid to the window
         self.add(grid)
 
-class GridApplication(Gtk.Application):
+class MyApplication(Gtk.Application):
     def __init__(self):
-        Gtk.Application.__init__(self, application_id="org.gtk.example.separator")
+        Gtk.Application.__init__(self)
 
     def do_activate(self):
-	win = SeparatorsWindow(self)
+	win = MyWindow(self)
 	win.show_all()
 
-app = GridApplication()
+app = MyApplication()
 exit_status = app.run(sys.argv)
 sys.exit(exit_status)
